Index: chrome/browser/prefs/incognito_user_pref_store.h |
diff --git a/chrome/browser/prefs/overlay_persistent_pref_store.h b/chrome/browser/prefs/incognito_user_pref_store.h |
similarity index 68% |
rename from chrome/browser/prefs/overlay_persistent_pref_store.h |
rename to chrome/browser/prefs/incognito_user_pref_store.h |
index 47ce6afbf61dc09365e07bb6f3433dfb171644ff..b5be17eb7c66b728feb9a24615738884c9bc1da0 100644 |
--- a/chrome/browser/prefs/overlay_persistent_pref_store.h |
+++ b/chrome/browser/prefs/incognito_user_pref_store.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef CHROME_BROWSER_PREFS_OVERLAY_PERSISTENT_PREF_STORE_H_ |
-#define CHROME_BROWSER_PREFS_OVERLAY_PERSISTENT_PREF_STORE_H_ |
+#ifndef CHROME_BROWSER_PREFS_INCOGNITO_USER_PREF_STORE_H_ |
+#define CHROME_BROWSER_PREFS_INCOGNITO_USER_PREF_STORE_H_ |
#pragma once |
#include <string> |
@@ -14,18 +14,18 @@ |
#include "chrome/browser/prefs/pref_value_map.h" |
#include "chrome/common/persistent_pref_store.h" |
-// PersistentPrefStore that directs all write operations into a in-memory |
+// PersistentPrefStore that directs all write operations into an in-memory |
// PrefValueMap. Read operations are first answered by the PrefValueMap. |
// If the PrefValueMap does not contain a value for the requested key, |
// the look-up is passed on to an underlying PersistentPrefStore |underlay_|. |
-class OverlayPersistentPrefStore : public PersistentPrefStore, |
- public PrefStore::Observer { |
+class IncognitoUserPrefStore : public PersistentPrefStore, |
+ public PrefStore::Observer { |
public: |
- explicit OverlayPersistentPrefStore(PersistentPrefStore* underlay); |
- virtual ~OverlayPersistentPrefStore(); |
+ explicit IncognitoUserPrefStore(PersistentPrefStore* underlay); |
+ virtual ~IncognitoUserPrefStore(); |
// Returns true if a value has been set for the |key| in this |
// OverlayPersistentPrefStore, i.e. if it potentially overrides a value |
// from the |underlay_|. |
virtual bool IsSetInOverlay(const std::string& key) const; |
@@ -55,11 +55,17 @@ class OverlayPersistentPrefStore : public PersistentPrefStore, |
virtual void OnPrefValueChanged(const std::string& key); |
virtual void OnInitializationCompleted(bool succeeded); |
+ // Returns true if |key| corresponds to a preference that shall be stored in |
+ // an in-memory PrefStore that is not persisted to disk. All preferences |
+ // that store information about the browsing history or behavior of the user |
+ // should have this property. |
+ virtual bool ShallBeStoredInOverlay(const std::string& key) const; |
+ |
ObserverList<PrefStore::Observer, true> observers_; |
PrefValueMap overlay_; |
scoped_refptr<PersistentPrefStore> underlay_; |
- DISALLOW_COPY_AND_ASSIGN(OverlayPersistentPrefStore); |
+ DISALLOW_COPY_AND_ASSIGN(IncognitoUserPrefStore); |
}; |
-#endif // CHROME_BROWSER_PREFS_OVERLAY_PERSISTENT_PREF_STORE_H_ |
+#endif // CHROME_BROWSER_PREFS_INCOGNITO_USER_PREF_STORE_H_ |
@@ -14,18 +14,18 @@ |
// Returns true if a value has been set for the |key| in this |
- // OverlayPersistentPrefStore, i.e. if it potentially overrides a value |
+ // IncognitoUserPrefStore, i.e. if it potentially overrides a value |
// from the |underlay_|. |
virtual bool IsSetInOverlay(const std::string& key) const; |